@@ -7,3 +7,5 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
+#undef GNOME_EXPLICIT_TRANSLATION_DOMAIN
+#undef GETTEXT_PACKAGE
