@@ -27,12 +27,13 @@
 #include <config.h>
 #include "eel-gdk-extensions.h"
 
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk/gdkx.h>
-#include <gdk/gdkprivate.h>
 #include "eel-glib-extensions.h"
 #include "eel-lib-self-check-functions.h"
 #include "eel-string.h"
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdkprivate.h>
+#include <gdk/gdk.h>
+#include <gdk/gdkx.h>
 #include <stdlib.h>
 
 #define GRADIENT_BAND_SIZE 4
@@ -68,15 +69,12 @@ eel_fill_rectangle (GdkDrawable *drawable,
  */
 void
 eel_fill_rectangle_with_color (GdkDrawable *drawable,
-				    GdkGC *gc,
-				    const GdkRectangle *rectangle,
-				    guint32 rgb)
+			       GdkGC *gc,
+			       const GdkRectangle *rectangle,
+			       guint32 rgb)
 {
 	GdkGCValues saved_values;
 	
-	/* FIXME bugzilla.eazel.com 1287: Workaround for a bug in gdk_rgb. */
-	gdk_rgb_init ();
-	
 	gdk_gc_get_values (gc, &saved_values);
 	gdk_rgb_gc_set_foreground (gc, rgb);
 	eel_fill_rectangle (drawable, gc, rectangle);
@@ -411,9 +409,21 @@ eel_gradient_set_bottom_color_spec (const char *gradient_spec,
  */
 void
 eel_gdk_color_parse_with_white_default (const char *color_spec,
-					     GdkColor *color)
+					GdkColor *color)
 {
-	if (color_spec == NULL || !gdk_color_parse (color_spec, color)) {
+	gboolean got_color;
+
+	got_color = FALSE;
+	if (color_spec != NULL) {
+		if (gdk_color_parse (color_spec, color)) {
+			got_color = TRUE;
+		} else if (eel_str_has_prefix (color_spec, "rgb:")) {
+			/* put rgb: parsing here? */
+			g_warning ("do we need rgb: parsing?");
+		}
+	}
+
+	if (!got_color) {
 		color->red = 0xFFFF;
 		color->green = 0xFFFF;
 		color->blue = 0xFFFF;
@@ -434,9 +444,7 @@ eel_parse_rgb_with_white_default (const char *color_spec)
 {
 	GdkColor color;
 
-	if (color_spec == NULL || !gdk_color_parse (color_spec, &color)) {
-		return EEL_RGB_COLOR_WHITE;
-	}
+	eel_gdk_color_parse_with_white_default (color_spec, &color);
 	return ((color.red << 8) & EEL_RGB_COLOR_RED)
 		| (color.green & EEL_RGB_COLOR_GREEN)
 		| ((color.blue >> 8) & EEL_RGB_COLOR_BLUE);
@@ -487,10 +495,10 @@ GdkColor
 eel_gdk_rgb_to_color (guint32 color)
 {
 	GdkColor result;
-	
-	result.red = (color & 0xff0000) >> 16 ;
-	result.green = (color & 0xff00);
-	result.blue = color << 8;
+
+	result.red = ((color >> 16) & 0xFF) * 0x101;
+	result.green = ((color >> 8) & 0xFF) * 0x101;
+	result.blue = (color & 0xff) * 0x101;
 	result.pixel = 0;
 
 	return result;
@@ -508,10 +516,7 @@ eel_gdk_rgb_to_color (guint32 color)
 char *
 eel_gdk_rgb_to_color_spec (const guint32 color)
 {
-	return g_strdup_printf("rgb:%04hX/%04hX/%04hX",
-			       EEL_RGBA_COLOR_GET_R (color) * 65535,
-			       EEL_RGBA_COLOR_GET_G (color) * 65535,
-			       EEL_RGBA_COLOR_GET_B (color) * 65535);
+	return g_strdup_printf ("#%06X", (guint) (color & 0xFFFFFF));
 }
 
 static guint32
@@ -629,7 +634,6 @@ eel_gdk_gc_choose_foreground_color (GdkGC *gc,
 	eel_gdk_choose_foreground_color (&temp, background);
 	rgb = eel_gdk_color_to_rgb (&temp);
 
-	gdk_rgb_init ();
 	gdk_rgb_gc_set_foreground (gc, rgb);
 }
 
@@ -686,13 +690,22 @@ eel_gdk_window_focus (GdkWindow *window, guint32 timestamp)
 
 void
 eel_gdk_window_set_wm_protocols (GdkWindow *window,
-				      GdkAtom *protocols,
-				      int nprotocols)
+				 GdkAtom *protocols,
+				 int nprotocols)
 {
-	/* This relies on the identity mapping from GdkAtoms to X Atoms */
+	Atom *atoms;
+	int i;
+
+	atoms = g_new (Atom, nprotocols);
+	for (i = 0; i < nprotocols; i++) {
+		atoms[i] = gdk_x11_atom_to_xatom (protocols[i]);
+	}
+
 	XSetWMProtocols (GDK_WINDOW_XDISPLAY (window),
 			 GDK_WINDOW_XWINDOW (window),
-			 protocols, nprotocols);
+			 atoms, nprotocols);
+
+	g_free (atoms);
 }
 
 void
@@ -751,39 +764,28 @@ eel_gdk_window_set_wm_hints_input (GdkWindow *window, gboolean status)
 void
 eel_gdk_window_set_invisible_cursor (GdkWindow *window)
 {
-	XColor foreColor, backColor;
-	GdkWindowPrivate *window_private;
-	Pixmap sourcePixmap, maskPixmap;
-	Cursor xcursor;
+	GdkBitmap *empty_bitmap;
+	GdkCursor *cursor;
+	GdkColor useless;
+	char invisible_cursor_bits[] = { 0x0 };	
+	
+	useless.red = useless.green = useless.blue = 0;
+	useless.pixel = 0;
+	
+	empty_bitmap = gdk_bitmap_create_from_data (window,
+						    invisible_cursor_bits,
+						    1, 1);
+	
+	cursor = gdk_cursor_new_from_pixmap (empty_bitmap,
+					     empty_bitmap,
+					     &useless,
+					     &useless, 0, 0);
 
-	char invisible_cursor_bits[]      = {0x0};
-	char invisible_cursor_mask_bits[] = {0x0};
+	gdk_window_set_cursor (window, cursor);
 
-	foreColor.pixel = 0L;
-	foreColor.red = foreColor.green = foreColor.blue = 0;
-	foreColor.flags = DoRed | DoGreen | DoBlue;
+	gdk_cursor_unref (cursor);
 
-	backColor.pixel = 255L;
-	backColor.red = backColor.green = backColor.blue = 65535;
-	backColor.flags = DoRed | DoGreen | DoBlue;
-
-	window_private = (GdkWindowPrivate *) window;
-  
-	sourcePixmap = XCreateBitmapFromData (window_private->xdisplay, window_private->xwindow,
-					            		  invisible_cursor_bits, 1, 1);
-	g_assert (sourcePixmap != 0);
-
-	maskPixmap = XCreateBitmapFromData (window_private->xdisplay, window_private->xwindow,
-					          			invisible_cursor_mask_bits, 1, 1);
-	g_assert (maskPixmap != 0);
-
-	xcursor = XCreatePixmapCursor (window_private->xdisplay, sourcePixmap, maskPixmap,
-					      		   &foreColor, &backColor, 0, 0);
-
-	XFreePixmap (window_private->xdisplay, sourcePixmap);
-	XFreePixmap (window_private->xdisplay, maskPixmap);
-
-	XDefineCursor (window_private->xdisplay, window_private->xwindow, xcursor);
+	g_object_unref (empty_bitmap);
 }
 
 EelGdkGeometryFlags
@@ -830,8 +832,8 @@ eel_gdk_parse_geometry (const char *string, int *x_return, int *y_return,
 static char *
 eel_gdk_color_as_hex_string (GdkColor color)
 {
-	return g_strdup_printf("rgb:%04hX/%04hX/%04hX",
-			       color.red, color.green, color.blue);
+	return g_strdup_printf ("%04X%04X%04X",
+				color.red, color.green, color.blue);
 }
 
 static char *
@@ -843,6 +845,16 @@ eel_self_check_parse (const char *color_spec)
 	return eel_gdk_color_as_hex_string (color);
 }
 
+static char *
+eel_self_check_gdk_rgb_to_color (guint32 color)
+{
+	GdkColor result;
+
+	result = eel_gdk_rgb_to_color (color);
+
+	return eel_gdk_color_as_hex_string (result);
+}
+
 void
 eel_self_check_gdk_extensions (void)
 {
@@ -940,12 +952,20 @@ eel_self_check_gdk_extensions (void)
 	EEL_CHECK_STRING_RESULT (eel_gradient_set_bottom_color_spec ("a:-b:h", "d"), "a:-d");
 
 	/* eel_gdk_color_parse_with_white_default */
-	EEL_CHECK_STRING_RESULT (eel_self_check_parse (""), "rgb:FFFF/FFFF/FFFF");
-	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("a"), "rgb:FFFF/FFFF/FFFF");
-	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("white"), "rgb:FFFF/FFFF/FFFF");
-	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("black"), "rgb:0000/0000/0000");
-	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("rgb:0123/4567/89AB"), "rgb:0123/4567/89AB");
+	EEL_CHECK_STRING_RESULT (eel_self_check_parse (""), "FFFFFFFFFFFF");
+	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("a"), "FFFFFFFFFFFF");
+	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("white"), "FFFFFFFFFFFF");
+	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("black"), "000000000000");
+	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("red"), "FFFF00000000");
+	EEL_CHECK_STRING_RESULT (eel_self_check_parse ("#012345"), "010123234545");
+	/* EEL_CHECK_STRING_RESULT (eel_self_check_parse ("rgb:0123/4567/89AB"), "#014589"); */
 
+	/* eel_gdk_rgb_to_color */
+	EEL_CHECK_STRING_RESULT (eel_self_check_gdk_rgb_to_color (EEL_RGB_COLOR_RED), "FFFF00000000");
+	EEL_CHECK_STRING_RESULT (eel_self_check_gdk_rgb_to_color (EEL_RGB_COLOR_BLACK), "000000000000");
+	EEL_CHECK_STRING_RESULT (eel_self_check_gdk_rgb_to_color (EEL_RGB_COLOR_WHITE), "FFFFFFFFFFFF");
+	EEL_CHECK_STRING_RESULT (eel_self_check_gdk_rgb_to_color (EEL_RGB_COLOR_PACK (0x01, 0x23, 0x45)), "010123234545");
+	
 	/* EEL_RGBA_COLOR_PACK */
 	EEL_CHECK_INTEGER_RESULT (EEL_RGBA_COLOR_PACK (0xFF, 0x00, 0x00, 00), EEL_RGB_COLOR_RED);
 	EEL_CHECK_INTEGER_RESULT (EEL_RGBA_COLOR_PACK (0x00, 0xFF, 0x00, 00), EEL_RGB_COLOR_GREEN);
@@ -1013,6 +1033,7 @@ eel_self_check_gdk_extensions (void)
 	EEL_CHECK_INTEGER_RESULT (EEL_RGBA_COLOR_GET_A (EEL_RGB_COLOR_BLUE), 0x00);
 	EEL_CHECK_INTEGER_RESULT (EEL_RGBA_COLOR_GET_A (EEL_RGB_COLOR_WHITE), 0x00);
 	EEL_CHECK_INTEGER_RESULT (EEL_RGBA_COLOR_GET_A (EEL_RGB_COLOR_BLACK), 0x00);
+
 }
 
 #endif /* ! EEL_OMIT_SELF_CHECK */
