@@ -27,11 +27,11 @@
 
 #include <eel/eel-image.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 GtkWidget *eel_image_new_with_background (const char *file_name);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* EEL_IMAGE_BACKGROUND_H */
 
