@@ -26,14 +26,17 @@
 
 #include "eel-image.h"
 
-#include "eel-gtk-macros.h"
-#include "eel-gdk-extensions.h"
-#include "eel-gtk-extensions.h"
-#include "eel-gdk-pixbuf-extensions.h"
 #include "eel-art-gtk-extensions.h"
-#include "eel-string.h"
-#include "eel-lib-self-check-functions.h"
 #include "eel-debug-drawing.h"
+#include "eel-gdk-extensions.h"
+#include "eel-gdk-pixbuf-extensions.h"
+#include "eel-gtk-extensions.h"
+#include "eel-gtk-macros.h"
+#include "eel-lib-self-check-functions.h"
+#include "eel-marshal.h"
+#include "eel-string.h"
+#include <gtk/gtkpixmap.h>
+#include <gtk/gtksignal.h>
 
 /* Arguments */
 enum
@@ -42,13 +45,8 @@ enum
 	ARG_BACKGROUND_MODE,
 	ARG_IS_SMOOTH,
 	ARG_PIXBUF,
+	ARG_PIXBUF_INSENSITIVE_OPACITY,
 	ARG_PIXBUF_OPACITY,
-	ARG_TILE_HEIGHT,
-	ARG_TILE_MODE_HORIZONTAL,
-	ARG_TILE_MODE_VERTICAL,
-	ARG_TILE_OPACITY,
-	ARG_TILE_PIXBUF,
-	ARG_TILE_WIDTH
 };
 
 /* Signals */
@@ -67,17 +65,10 @@ struct EelImageDetails
 {
 	gboolean is_smooth;
 
-	/* Tile attributes */
-	GdkPixbuf *tile_pixbuf;
-	int tile_opacity;
-	int tile_width;
-	int tile_height;
-	EelSmoothTileMode tile_mode_vertical;
-	EelSmoothTileMode tile_mode_horizontal;
-
 	/* Pixbuf */
 	GdkPixbuf *pixbuf;
 	int pixbuf_opacity;
+	int pixbuf_insensitive_opacity;
 
 	/* Background */
 	EelSmoothBackgroundMode background_mode;
@@ -85,10 +76,11 @@ struct EelImageDetails
 	gboolean never_smooth;
 };
 
+static void          eel_image_class_init     (EelImageClass  *image_class);
+static void          eel_image_init           (EelImage       *image);
+static void          eel_image_finalize             (GObject        *object);
+
 /* GtkObjectClass methods */
-static void          eel_image_initialize_class     (EelImageClass  *image_class);
-static void          eel_image_initialize           (EelImage       *image);
-static void          eel_image_destroy              (GtkObject      *object);
 static void          eel_image_set_arg              (GtkObject      *object,
 						     GtkArg         *arg,
 						     guint           arg_id);
@@ -108,20 +100,20 @@ static void          eel_image_set_is_smooth_signal (GtkWidget      *widget,
 /* Private EelImage methods */
 static EelDimensions image_get_pixbuf_dimensions    (const EelImage *image);
 static ArtIRect      image_get_pixbuf_bounds        (const EelImage *image);
-static EelDimensions image_get_tile_dimensions      (const EelImage *image);
 static gboolean      image_is_smooth                (const EelImage *image);
 
-EEL_DEFINE_CLASS_BOILERPLATE (EelImage, eel_image, GTK_TYPE_MISC)
+EEL_CLASS_BOILERPLATE (EelImage, eel_image, GTK_TYPE_MISC)
 
 /* Class init methods */
-	static void
-eel_image_initialize_class (EelImageClass *image_class)
+static void
+eel_image_class_init (EelImageClass *image_class)
 {
 	GtkObjectClass *object_class = GTK_OBJECT_CLASS (image_class);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (image_class);
 
+	G_OBJECT_CLASS (object_class)->finalize = eel_image_finalize;
+
 	/* GtkObjectClass */
-	object_class->destroy = eel_image_destroy;
 	object_class->set_arg = eel_image_set_arg;
 	object_class->get_arg = eel_image_get_arg;
 	
@@ -135,66 +127,44 @@ eel_image_initialize_class (EelImageClass *image_class)
 	/* Signals */
 	image_signals[DRAW_BACKGROUND] = gtk_signal_new ("draw_background",
 							 GTK_RUN_LAST,
-							 object_class->type,
-							 0,
-							 gtk_marshal_NONE__POINTER_POINTER,
-							 GTK_TYPE_NONE, 
+							 GTK_CLASS_TYPE (object_class),
+							 G_STRUCT_OFFSET (EelImageClass, draw_background),
+							 eel_marshal_VOID__OBJECT_POINTER,
+							 G_TYPE_NONE, 
 							 2,
-							 GTK_TYPE_POINTER,
-							 GTK_TYPE_POINTER);
+							 GDK_TYPE_PIXBUF,
+							 G_TYPE_POINTER);
 
 	image_signals[SET_IS_SMOOTH] = gtk_signal_new ("set_is_smooth",
 						       GTK_RUN_LAST,
-						       object_class->type,
-						       GTK_SIGNAL_OFFSET (EelImageClass, set_is_smooth),
-						       gtk_marshal_NONE__BOOL,
-						       GTK_TYPE_NONE, 
+						       GTK_CLASS_TYPE (object_class),
+						       G_STRUCT_OFFSET (EelImageClass, set_is_smooth),
+						       gtk_marshal_VOID__BOOLEAN,
+						       G_TYPE_NONE, 
 						       1,
-						       GTK_TYPE_BOOL);
+						       G_TYPE_BOOLEAN);
 	
-	gtk_object_class_add_signals (object_class, image_signals, LAST_SIGNAL);
-
 	/* Arguments */
 	gtk_object_add_arg_type ("EelImage::is_smooth",
-				 GTK_TYPE_BOOL,
+				 G_TYPE_BOOLEAN,
 				 GTK_ARG_READWRITE,
 				 ARG_IS_SMOOTH);
 	gtk_object_add_arg_type ("EelImage::pixbuf",
-				 GTK_TYPE_POINTER,
+				 G_TYPE_POINTER,
 				 GTK_ARG_READWRITE,
 				 ARG_PIXBUF);
 	gtk_object_add_arg_type ("EelImage::pixbuf_opacity",
-				 GTK_TYPE_INT,
+				 G_TYPE_INT,
 				 GTK_ARG_READWRITE,
 				 ARG_PIXBUF_OPACITY);
+	gtk_object_add_arg_type ("EelImage::pixbuf_insensitive_opacity",
+				 G_TYPE_INT,
+				 GTK_ARG_READWRITE,
+				 ARG_PIXBUF_INSENSITIVE_OPACITY);
 	gtk_object_add_arg_type ("EelImage::background_mode",
-				 GTK_TYPE_UINT,
+				 G_TYPE_UINT,
 				 GTK_ARG_READWRITE,
 				 ARG_BACKGROUND_MODE);
-	gtk_object_add_arg_type ("EelImage::tile_pixbuf",
-				 GTK_TYPE_POINTER,
-				 GTK_ARG_READWRITE,
-				 ARG_TILE_PIXBUF);
-	gtk_object_add_arg_type ("EelImage::tile_opacity",
-				 GTK_TYPE_INT,
-				 GTK_ARG_READWRITE,
-				 ARG_TILE_OPACITY);
-	gtk_object_add_arg_type ("EelImage::tile_width",
-				 GTK_TYPE_INT,
-				 GTK_ARG_READWRITE,
-				 ARG_TILE_WIDTH);
-	gtk_object_add_arg_type ("EelImage::tile_height",
-				 GTK_TYPE_INT,
-				 GTK_ARG_READWRITE,
-				 ARG_TILE_HEIGHT);
-	gtk_object_add_arg_type ("EelImage::tile_mode_vertical",
-				 GTK_TYPE_UINT,
-				 GTK_ARG_READWRITE,
-				 ARG_TILE_MODE_VERTICAL);
-	gtk_object_add_arg_type ("EelImage::tile_mode_horizontal",
-				 GTK_TYPE_UINT,
-				 GTK_ARG_READWRITE,
-				 ARG_TILE_MODE_HORIZONTAL);
 
 	/* Make this class inherit the same kind of theme stuff as GtkPixmap */
 	eel_gtk_class_name_make_like_existing_type ("EelImage", GTK_TYPE_PIXMAP);
@@ -204,7 +174,7 @@ eel_image_initialize_class (EelImageClass *image_class)
 }
 
 void
-eel_image_initialize (EelImage *image)
+eel_image_init (EelImage *image)
 {
 	GTK_WIDGET_UNSET_FLAGS (image, GTK_CAN_FOCUS);
 	GTK_WIDGET_SET_FLAGS (image, GTK_NO_WINDOW);
@@ -212,35 +182,25 @@ eel_image_initialize (EelImage *image)
 	image->details = g_new0 (EelImageDetails, 1);
 
 	image->details->pixbuf_opacity = EEL_OPACITY_FULLY_OPAQUE;
-	image->details->tile_opacity = EEL_OPACITY_FULLY_OPAQUE;
- 	image->details->tile_width = EEL_SMOOTH_TILE_EXTENT_FULL;
- 	image->details->tile_height = EEL_SMOOTH_TILE_EXTENT_FULL;
-	image->details->tile_mode_vertical = EEL_SMOOTH_TILE_SELF;
-	image->details->tile_mode_horizontal = EEL_SMOOTH_TILE_SELF;
+	image->details->pixbuf_insensitive_opacity = EEL_OPACITY_FULLY_OPAQUE / 3;
 	image->details->background_mode = EEL_SMOOTH_BACKGROUND_GTK;
 
 	eel_smooth_widget_register (GTK_WIDGET (image));
 }
 
-/* GtkObjectClass methods */
 static void
-eel_image_destroy (GtkObject *object)
+eel_image_finalize (GObject *object)
 {
  	EelImage *image;
 	
-	g_return_if_fail (EEL_IS_IMAGE (object));
-
 	image = EEL_IMAGE (object);
 
-	eel_gdk_pixbuf_unref_if_not_null (image->details->tile_pixbuf);
-	image->details->tile_pixbuf = NULL;
-
 	g_free (image->details);
 
-	/* Chain destroy */
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
+/* GtkObjectClass methods */
 static void
 eel_image_set_arg (GtkObject *object,
 		   GtkArg *arg,
@@ -262,6 +222,10 @@ eel_image_set_arg (GtkObject *object,
 		eel_image_set_pixbuf_opacity (image, GTK_VALUE_INT (*arg));
 		break;
 
+	case ARG_PIXBUF_INSENSITIVE_OPACITY:
+		eel_image_set_pixbuf_insensitive_opacity (image, GTK_VALUE_INT (*arg));
+		break;
+
 	case ARG_BACKGROUND_MODE:
 		eel_image_set_background_mode (image, GTK_VALUE_UINT (*arg));
 		break;
@@ -270,30 +234,6 @@ eel_image_set_arg (GtkObject *object,
 		eel_image_set_pixbuf (image, (GdkPixbuf *) GTK_VALUE_POINTER (*arg));
 		break;
 
-	case ARG_TILE_OPACITY:
-		eel_image_set_tile_opacity (image, GTK_VALUE_INT (*arg));
-		break;
-
-	case ARG_TILE_PIXBUF:
-		eel_image_set_tile_pixbuf (image, (GdkPixbuf *) GTK_VALUE_POINTER (*arg));
-		break;
-		
-	case ARG_TILE_WIDTH:
-		eel_image_set_tile_width (image, GTK_VALUE_INT (*arg));
-		break;
-
-	case ARG_TILE_HEIGHT:
-		eel_image_set_tile_height (image, GTK_VALUE_INT (*arg));
-		break;
-
-	case ARG_TILE_MODE_VERTICAL:
-		eel_image_set_tile_mode_vertical (image, GTK_VALUE_UINT (*arg));
-		break;
-
-	case ARG_TILE_MODE_HORIZONTAL:
-		eel_image_set_tile_mode_horizontal (image, GTK_VALUE_UINT (*arg));
-		break;
-
  	default:
 		g_assert_not_reached ();
 	}
@@ -320,6 +260,10 @@ eel_image_get_arg (GtkObject *object,
 		GTK_VALUE_INT (*arg) = eel_image_get_pixbuf_opacity (image);
 		break;
 		
+	case ARG_PIXBUF_INSENSITIVE_OPACITY:
+		GTK_VALUE_INT (*arg) = eel_image_get_pixbuf_insensitive_opacity (image);
+		break;
+		
 	case ARG_BACKGROUND_MODE:
 		GTK_VALUE_UINT (*arg) = eel_image_get_background_mode (image);
 		break;
@@ -328,30 +272,6 @@ eel_image_get_arg (GtkObject *object,
 		GTK_VALUE_POINTER (*arg) = eel_image_get_pixbuf (image);
 		break;
 
-	case ARG_TILE_OPACITY:
-		GTK_VALUE_INT (*arg) = eel_image_get_tile_opacity (image);
-		break;
-		
-	case ARG_TILE_PIXBUF:
-		GTK_VALUE_POINTER (*arg) = eel_image_get_tile_pixbuf (image);
-		break;
-
-	case ARG_TILE_WIDTH:
-		GTK_VALUE_INT (*arg) = eel_image_get_tile_width (image);
-		break;
-
-	case ARG_TILE_HEIGHT:
-		GTK_VALUE_INT (*arg) = eel_image_get_tile_height (image);
-		break;
-
-	case ARG_TILE_MODE_VERTICAL:
-		GTK_VALUE_UINT (*arg) = eel_image_get_tile_mode_vertical (image);
-		break;
-
-	case ARG_TILE_MODE_HORIZONTAL:
-		GTK_VALUE_UINT (*arg) = eel_image_get_tile_mode_horizontal (image);
-		break;
-
  	default:
 		g_assert_not_reached ();
 	}
@@ -365,7 +285,6 @@ eel_image_size_request (GtkWidget *widget,
 	EelImage *image;
 
 	EelDimensions pixbuf_dimensions;
-	EelDimensions tile_dimensions;
 	EelDimensions preferred_dimensions;
 	
 	g_return_if_fail (EEL_IS_IMAGE (widget));
@@ -374,12 +293,8 @@ eel_image_size_request (GtkWidget *widget,
  	image = EEL_IMAGE (widget);
 	
 	pixbuf_dimensions = image_get_pixbuf_dimensions (image);
-	tile_dimensions = image_get_tile_dimensions (image);
 	preferred_dimensions = eel_smooth_widget_get_preferred_dimensions (widget,
-									   pixbuf_dimensions,
-									   tile_dimensions,
-									   image->details->tile_width,
-									   image->details->tile_height);
+									   pixbuf_dimensions);
    	requisition->width = preferred_dimensions.width;
    	requisition->height = preferred_dimensions.height;
 }
@@ -452,9 +367,7 @@ eel_image_expose_event (GtkWidget *widget,
  	EelImage *image;
 	ArtIRect dirty_area;
 	ArtIRect screen_dirty_area;
-
 	ArtIRect pixbuf_bounds;
-	ArtIRect tile_bounds;
 
 	g_return_val_if_fail (EEL_IS_IMAGE (widget), TRUE);
 	g_return_val_if_fail (GTK_WIDGET_REALIZED (widget), TRUE);
@@ -464,13 +377,9 @@ eel_image_expose_event (GtkWidget *widget,
  	image = EEL_IMAGE (widget);
 
 	pixbuf_bounds = image_get_pixbuf_bounds (image);
-	tile_bounds = eel_smooth_widget_get_tile_bounds (widget,
-							 image->details->tile_pixbuf,
-							 image->details->tile_width,
-							 image->details->tile_height);
 	
 	/* Check for the dumb case when theres nothing to do */
-	if (image->details->pixbuf == NULL && image->details->tile_pixbuf == NULL) {
+	if (image->details->pixbuf == NULL) {
 		return TRUE;
 	}
 
@@ -489,13 +398,10 @@ eel_image_expose_event (GtkWidget *widget,
 				 image_is_smooth (image),
 				 image->details->background_mode,
 				 image->details->solid_background_color,
-				 image->details->tile_pixbuf,
-				 tile_bounds,
-				 image->details->tile_opacity,
-				 image->details->tile_mode_vertical,
-				 image->details->tile_mode_horizontal,
 				 pixbuf_bounds,
-				 image->details->pixbuf_opacity,
+				 (widget->state == GTK_STATE_INSENSITIVE
+				  ? image->details->pixbuf_insensitive_opacity
+				  : image->details->pixbuf_opacity),
 				 screen_dirty_area,
 				 image_paint_pixbuf_callback,
 				 image_composite_pixbuf_callback,
@@ -558,23 +464,6 @@ image_get_pixbuf_bounds (const EelImage *image)
 	return pixbuf_bounds;
 }
 
-static EelDimensions
-image_get_tile_dimensions (const EelImage *image)
-{
-	EelDimensions tile_dimensions;
-
-	g_return_val_if_fail (EEL_IS_IMAGE (image), eel_dimensions_empty);
-
-	if (!image->details->tile_pixbuf) {
-		return eel_dimensions_empty;
-	}
-	
-	tile_dimensions.width = gdk_pixbuf_get_width (image->details->tile_pixbuf);
-	tile_dimensions.height = gdk_pixbuf_get_height (image->details->tile_pixbuf);
-
-	return tile_dimensions;
-}
-
 gboolean
 image_is_smooth (const EelImage *image)
 {
@@ -630,49 +519,6 @@ eel_image_get_is_smooth (const EelImage *image)
 	return image_is_smooth (image);
 }
 
-/**
- * eel_image_set_tile_pixbuf:
- *
- * @image: A EelImage
- * @pixbuf:          The new tile pixbuf
- *
- * Change the tile pixbuf.  A 'pixbuf' value of NULL, means dont use a
- * tile pixbuf - this is the default behavior for the widget.
- */
-void
-eel_image_set_tile_pixbuf (EelImage *image,
-			   GdkPixbuf *pixbuf)
-{
-	g_return_if_fail (EEL_IS_IMAGE (image));
-	
-	if (pixbuf != image->details->tile_pixbuf) {
-		eel_gdk_pixbuf_unref_if_not_null (image->details->tile_pixbuf);
-		eel_gdk_pixbuf_ref_if_not_null (pixbuf);
-		
-		image->details->tile_pixbuf = pixbuf;
-
-		gtk_widget_queue_draw (GTK_WIDGET (image));
-	}
-}
-
-/**
- * eel_image_get_tile_pixbuf:
- *
- * @image: A EelImage
- *
- * Return value: A reference to the tile_pixbuf.  Needs to be unreferenced with 
- * gdk_pixbuf_unref()
- */
-GdkPixbuf*
-eel_image_get_tile_pixbuf (const EelImage *image)
-{
-	g_return_val_if_fail (EEL_IS_IMAGE (image), NULL);
-
-	eel_gdk_pixbuf_ref_if_not_null (image->details->tile_pixbuf);
-	
-	return image->details->tile_pixbuf;
-}
-
 void
 eel_image_set_pixbuf (EelImage *image,
 		      GdkPixbuf *pixbuf)
@@ -696,11 +542,11 @@ eel_image_set_pixbuf_from_file_name (EelImage *image,
 	g_return_if_fail (EEL_IS_IMAGE (image));
 	g_return_if_fail (file_name != NULL);
 
-	pixbuf = gdk_pixbuf_new_from_file (file_name);			
+	pixbuf = gdk_pixbuf_new_from_file (file_name, NULL);			
 	
 	if (pixbuf != NULL) {
 		eel_image_set_pixbuf (image, pixbuf);	
-		gdk_pixbuf_unref (pixbuf);
+		g_object_unref (pixbuf);
 	}
 }
 
@@ -740,157 +586,30 @@ eel_image_get_pixbuf_opacity (const EelImage *image)
 }
 
 void
-eel_image_set_tile_opacity (EelImage *image,
-			    int tile_opacity)
+eel_image_set_pixbuf_insensitive_opacity (EelImage *image,
+					  int pixbuf_insensitive_opacity)
 {
 	g_return_if_fail (EEL_IS_IMAGE (image));
-	g_return_if_fail (tile_opacity >= EEL_OPACITY_FULLY_TRANSPARENT);
-	g_return_if_fail (tile_opacity <= EEL_OPACITY_FULLY_OPAQUE);
+	g_return_if_fail (pixbuf_insensitive_opacity >= EEL_OPACITY_FULLY_TRANSPARENT);
+	g_return_if_fail (pixbuf_insensitive_opacity <= EEL_OPACITY_FULLY_OPAQUE);
 
-	if (image->details->tile_opacity == tile_opacity) {
+	if (image->details->pixbuf_insensitive_opacity == pixbuf_insensitive_opacity) {
 		return;
 	}
 
-	image->details->tile_opacity = tile_opacity;
+	image->details->pixbuf_insensitive_opacity = pixbuf_insensitive_opacity;
 
-	gtk_widget_queue_draw (GTK_WIDGET (image));
+	if (!GTK_WIDGET_SENSITIVE (image)) {
+		gtk_widget_queue_draw (GTK_WIDGET (image));
+	}
 }
 
 int
-eel_image_get_tile_opacity (const EelImage *image)
+eel_image_get_pixbuf_insensitive_opacity (const EelImage *image)
 {
 	g_return_val_if_fail (EEL_IS_IMAGE (image), EEL_OPACITY_FULLY_OPAQUE);
 
-	return image->details->tile_opacity;
-}
-
-void
-eel_image_set_tile_width (EelImage *image,
-			  int tile_width)
-{
-	g_return_if_fail (EEL_IS_IMAGE (image));
-	g_return_if_fail (tile_width >= EEL_SMOOTH_TILE_EXTENT_ONE_STEP);
-	
-	if (image->details->tile_width == tile_width) {
-		return;
-	}
-
-	image->details->tile_width = tile_width;
-
-	gtk_widget_queue_resize (GTK_WIDGET (image));
-}
-
-/**
- * eel_image_get_tile_width:
- *
- * @image: A EelImage
- *
- * Return value: The tile width.
- */
-int
-eel_image_get_tile_width (const EelImage *image)
-{
-	g_return_val_if_fail (EEL_IS_IMAGE (image), 0);
-
-	return image->details->tile_width;
-}
-
-void
-eel_image_set_tile_height (EelImage *image,
-			   int tile_height)
-{
-	g_return_if_fail (EEL_IS_IMAGE (image));
-	g_return_if_fail (tile_height >= EEL_SMOOTH_TILE_EXTENT_ONE_STEP);
-	
-	if (image->details->tile_height == tile_height) {
-		return;
-	}
-
-	image->details->tile_height = tile_height;
-
-	gtk_widget_queue_resize (GTK_WIDGET (image));
-}
-
-/**
- * eel_image_get_tile_height:
- *
- * @image: A EelImage
- *
- * Return value: The tile height.
- */
-int
-eel_image_get_tile_height (const EelImage *image)
-{
-	g_return_val_if_fail (EEL_IS_IMAGE (image), 0);
-
-	return image->details->tile_height;
-}
-
-void
-eel_image_set_tile_mode_vertical (EelImage *image,
-				  EelSmoothTileMode tile_mode_vertical)
-{
-	g_return_if_fail (EEL_IS_IMAGE (image));
-	g_return_if_fail (tile_mode_vertical >= EEL_SMOOTH_TILE_SELF);
-	g_return_if_fail (tile_mode_vertical <= EEL_SMOOTH_TILE_ANCESTOR);
-
-	if (image->details->tile_mode_vertical == tile_mode_vertical) {
-		return;
-	}
-
-	image->details->tile_mode_vertical = tile_mode_vertical;
-
-	gtk_widget_queue_draw (GTK_WIDGET (image));
-}
-
-EelSmoothTileMode
-eel_image_get_tile_mode_vertical (const EelImage *image)
-{
-	g_return_val_if_fail (EEL_IS_IMAGE (image), 0);
-	
-	return image->details->tile_mode_vertical;
-}
-
-void
-eel_image_set_tile_mode_horizontal (EelImage *image,
-				    EelSmoothTileMode tile_mode_horizontal)
-{
-	g_return_if_fail (EEL_IS_IMAGE (image));
-	g_return_if_fail (tile_mode_horizontal >= EEL_SMOOTH_TILE_SELF);
-	g_return_if_fail (tile_mode_horizontal <= EEL_SMOOTH_TILE_ANCESTOR);
-
-	if (image->details->tile_mode_horizontal == tile_mode_horizontal) {
-		return;
-	}
-
-	image->details->tile_mode_horizontal = tile_mode_horizontal;
-
-	gtk_widget_queue_draw (GTK_WIDGET (image));
-}
-
-EelSmoothTileMode
-eel_image_get_tile_mode_horizontal (const EelImage *image)
-{
-	g_return_val_if_fail (EEL_IS_IMAGE (image), 0);
-	
-	return image->details->tile_mode_horizontal;
-}
-
-void
-eel_image_set_tile_pixbuf_from_file_name (EelImage *image,
-					  const char *tile_file_name)
-{
-	GdkPixbuf *tile_pixbuf;
-
-	g_return_if_fail (EEL_IS_IMAGE (image));
-	g_return_if_fail (tile_file_name != NULL);
-
-	tile_pixbuf = gdk_pixbuf_new_from_file (tile_file_name);
-	
-	if (tile_pixbuf != NULL) {
-		eel_image_set_tile_pixbuf (image, tile_pixbuf);
-		gdk_pixbuf_unref (tile_pixbuf);
-	}
+	return image->details->pixbuf_insensitive_opacity;
 }
 
 void
@@ -950,7 +669,6 @@ eel_image_get_solid_background_color (const EelImage *image)
  * @x_padding: Horizontal padding.
  * @y_padding: Vertical padding.
  * @background_color: Background color.
- * @tile_pixbuf: A GdkPixbuf or NULL.
  *
  * Create an image with a solid background.
  *
@@ -963,8 +681,7 @@ eel_image_new_solid (GdkPixbuf *pixbuf,
 		     float y_alignment,
 		     int x_padding,
 		     int y_padding,
-		     guint32 background_color,
-		     GdkPixbuf *tile_pixbuf)
+		     guint32 background_color)
 {
 	EelImage *image;
 
@@ -980,10 +697,6 @@ eel_image_new_solid (GdkPixbuf *pixbuf,
 	gtk_misc_set_padding (GTK_MISC (image), x_padding, y_padding);
 	gtk_misc_set_alignment (GTK_MISC (image), x_alignment, y_alignment);
 	
-	if (tile_pixbuf != NULL) {
-		eel_image_set_tile_pixbuf (image, tile_pixbuf);
-	}
-	
 	return GTK_WIDGET (image);
 }
 
