@@ -32,9 +32,9 @@
 #include "eel-gtk-extensions.h"
 #include "eel-gtk-macros.h"
 #include "eel-image.h"
-#include "eel-label.h"
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkcheckbutton.h>
+#include <gtk/gtksignal.h>
 #include <gtk/gtktogglebutton.h>
 
 #define DEFAULT_SPACING 0
@@ -77,10 +77,11 @@ struct EelLabeledImageDetails
 	gboolean fill;
 };
 
+static void          eel_labeled_image_class_init   (EelLabeledImageClass  *labeled_image_class);
+static void          eel_labeled_image_init         (EelLabeledImage       *image);
+static void          eel_labeled_image_finalize           (GObject               *object);
+
 /* GtkObjectClass methods */
-static void          eel_labeled_image_initialize_class   (EelLabeledImageClass  *labeled_image_class);
-static void          eel_labeled_image_initialize         (EelLabeledImage       *image);
-static void          eel_labeled_image_destroy            (GtkObject             *object);
 static void          eel_labeled_image_set_arg            (GtkObject             *object,
 							   GtkArg                *arg,
 							   guint                  arg_id);
@@ -92,8 +93,6 @@ static void          eel_labeled_image_size_request       (GtkWidget
 							   GtkRequisition        *requisition);
 static int           eel_labeled_image_expose_event       (GtkWidget             *widget,
 							   GdkEventExpose        *event);
-static void          eel_labeled_image_draw               (GtkWidget             *widget,
-							   GdkRectangle          *area);
 static void          eel_labeled_image_size_allocate      (GtkWidget             *widget,
 							   GtkAllocation         *allocation);
 static void          eel_labeled_image_map                (GtkWidget             *widget);
@@ -120,18 +119,19 @@ static void          labeled_image_update_alignments      (EelLabeledImage
 static gboolean      labeled_image_show_label             (const EelLabeledImage *labeled_image);
 static gboolean      labeled_image_show_image             (const EelLabeledImage *labeled_image);
 
-EEL_DEFINE_CLASS_BOILERPLATE (EelLabeledImage, eel_labeled_image, GTK_TYPE_CONTAINER)
+EEL_CLASS_BOILERPLATE (EelLabeledImage, eel_labeled_image, GTK_TYPE_CONTAINER)
 
 /* Class init methods */
-	static void
-eel_labeled_image_initialize_class (EelLabeledImageClass *labeled_image_class)
+static void
+eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 {
 	GtkObjectClass *object_class = GTK_OBJECT_CLASS (labeled_image_class);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (labeled_image_class);
 	GtkContainerClass *container_class = GTK_CONTAINER_CLASS (labeled_image_class);
 
+	G_OBJECT_CLASS (object_class)->finalize = eel_labeled_image_finalize;
+
 	/* GtkObjectClass */
-	object_class->destroy = eel_labeled_image_destroy;
 	object_class->set_arg = eel_labeled_image_set_arg;
 	object_class->get_arg = eel_labeled_image_get_arg;
 	
@@ -139,7 +139,6 @@ eel_labeled_image_initialize_class (EelLabeledImageClass *labeled_image_class)
  	widget_class->size_request = eel_labeled_image_size_request;
 	widget_class->size_allocate = eel_labeled_image_size_allocate;
  	widget_class->expose_event = eel_labeled_image_expose_event;
- 	widget_class->draw = eel_labeled_image_draw;
 	widget_class->map = eel_labeled_image_map;
 	widget_class->unmap = eel_labeled_image_unmap;
 
@@ -150,7 +149,7 @@ eel_labeled_image_initialize_class (EelLabeledImageClass *labeled_image_class)
   
 	/* Arguments */
 	gtk_object_add_arg_type ("EelLabeledImage::pixbuf",
-				 GTK_TYPE_POINTER,
+				 G_TYPE_POINTER,
 				 GTK_ARG_READWRITE,
 				 ARG_PIXBUF);
 	gtk_object_add_arg_type ("EelLabeledImage::label",
@@ -162,41 +161,41 @@ eel_labeled_image_initialize_class (EelLabeledImageClass *labeled_image_class)
 				 GTK_ARG_READWRITE,
 				 ARG_LABEL_POSITION);
 	gtk_object_add_arg_type ("EelLabeledImage::show_label",
-				 GTK_TYPE_BOOL,
+				 G_TYPE_BOOLEAN,
 				 GTK_ARG_READWRITE,
 				 ARG_SHOW_LABEL);
 	gtk_object_add_arg_type ("EelLabeledImage::show_image",
-				 GTK_TYPE_BOOL,
+				 G_TYPE_BOOLEAN,
 				 GTK_ARG_READWRITE,
 				 ARG_SHOW_IMAGE);
 	gtk_object_add_arg_type ("EelLabeledImage::spacing",
-				 GTK_TYPE_UINT,
+				 G_TYPE_UINT,
 				 GTK_ARG_READWRITE,
 				 ARG_SPACING);
 	gtk_object_add_arg_type ("EelLabeledImage::x_padding",
-				 GTK_TYPE_INT,
+				 G_TYPE_INT,
 				 GTK_ARG_READWRITE,
 				 ARG_X_PADDING);
 	gtk_object_add_arg_type ("EelLabeledImage::y_padding",
-				 GTK_TYPE_INT,
+				 G_TYPE_INT,
 				 GTK_ARG_READWRITE,
 				 ARG_Y_PADDING);
 	gtk_object_add_arg_type ("EelLabeledImage::x_alignment",
-				 GTK_TYPE_FLOAT,
+				 G_TYPE_FLOAT,
 				 GTK_ARG_READWRITE,
 				 ARG_X_ALIGNMENT);
 	gtk_object_add_arg_type ("EelLabeledImage::y_alignment",
-				 GTK_TYPE_FLOAT,
+				 G_TYPE_FLOAT,
 				 GTK_ARG_READWRITE,
 				 ARG_Y_ALIGNMENT);
 	gtk_object_add_arg_type ("EelLabeledImage::fill",
-				 GTK_TYPE_BOOL,
+				 G_TYPE_BOOLEAN,
 				 GTK_ARG_READWRITE,
 				 ARG_FILL);
 }
 
 void
-eel_labeled_image_initialize (EelLabeledImage *labeled_image)
+eel_labeled_image_init (EelLabeledImage *labeled_image)
 {
 	GTK_WIDGET_SET_FLAGS (labeled_image, GTK_NO_WINDOW);
 
@@ -214,32 +213,19 @@ eel_labeled_image_initialize (EelLabeledImage *labeled_image)
 	eel_labeled_image_set_fill (labeled_image, FALSE);
 }
 
-/* GtkObjectClass methods */
 static void
-eel_labeled_image_destroy (GtkObject *object)
+eel_labeled_image_finalize (GObject *object)
 {
  	EelLabeledImage *labeled_image;
 	
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (object));
-
 	labeled_image = EEL_LABELED_IMAGE (object);
 
-	if (labeled_image->details->image != NULL) {
-		gtk_widget_destroy (labeled_image->details->image);
-		labeled_image->details->image = NULL;
-	}
-
-	if (labeled_image->details->label != NULL) {
-		gtk_widget_destroy (labeled_image->details->label);
-		labeled_image->details->label = NULL;
-	}
-
 	g_free (labeled_image->details);
 
-	/* Chain destroy */
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
+/* GtkObjectClass methods */
 static void
 eel_labeled_image_set_arg (GtkObject *object,
 			   GtkArg *arg,
@@ -440,30 +426,6 @@ eel_labeled_image_expose_event (GtkWidget *widget,
 	return FALSE;
 }
 
-static void
-eel_labeled_image_draw (GtkWidget *widget,
-			GdkRectangle *area)
-{
-	EelLabeledImage *labeled_image;
-	
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (widget));
-	g_return_if_fail (area != NULL);
-	
-  	labeled_image = EEL_LABELED_IMAGE (widget);
-	
-	if (labeled_image_show_label (labeled_image)) {
-		eel_gtk_container_child_draw (GTK_CONTAINER (widget),
-					      labeled_image->details->label,
-					      area);
-	}
-	
-	if (labeled_image_show_image (labeled_image)) {
-		eel_gtk_container_child_draw (GTK_CONTAINER (widget),
-					      labeled_image->details->image,
-					      area);
-	}
-}
-
 static void
 eel_labeled_image_map (GtkWidget *widget)
 {
@@ -504,8 +466,7 @@ static void
 eel_labeled_image_add (GtkContainer *container,
 		       GtkWidget *child)
 {
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (container));
-	g_return_if_fail (EEL_IS_LABEL (child) || EEL_IS_IMAGE (child));
+	g_return_if_fail (GTK_IS_LABEL (child) || EEL_IS_IMAGE (child));
 
 	eel_gtk_container_child_add (container, child);
 }
@@ -516,8 +477,7 @@ eel_labeled_image_remove (GtkContainer *container,
 {
 	EelLabeledImage *labeled_image;
 	
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (container));
-	g_return_if_fail (EEL_IS_LABEL (child) || EEL_IS_IMAGE (child));
+	g_return_if_fail (GTK_IS_LABEL (child) || EEL_IS_IMAGE (child));
 	
 	labeled_image = EEL_LABELED_IMAGE (container);;
 
@@ -1047,7 +1007,7 @@ labeled_image_ensure_label (EelLabeledImage *labeled_image)
 		return;
 	}
 
- 	labeled_image->details->label = eel_label_new (NULL);
+ 	labeled_image->details->label = gtk_label_new (NULL);
 	gtk_container_add (GTK_CONTAINER (labeled_image), labeled_image->details->label);
 	gtk_widget_show (labeled_image->details->label);
 }
@@ -1530,9 +1490,7 @@ eel_labeled_image_get_y_alignment (const EelLabeledImage *labeled_image)
  * By default the internal image and label wigets are sized to their natural
  * preferred geometry.  You can use the 'fill' attribute of LabeledImage
  * to have the internal widgets fill as much of the LabeledImage allocation
- * as is available.  This is useful if you install a tile_pixbuf and want it
- * to cover the whole widget, and not just the areas occupied by the internal
- * widgets.
+ * as is available.
  */
 void
 eel_labeled_image_set_fill (EelLabeledImage *labeled_image,
@@ -1733,12 +1691,12 @@ eel_labeled_image_check_button_new (const char *text,
 	 */
 	gtk_signal_connect_while_alive (GTK_OBJECT (check_button),
 					"leave",
-					GTK_SIGNAL_FUNC (button_leave_callback),
+					G_CALLBACK (button_leave_callback),
 					NULL,
 					GTK_OBJECT (check_button));
 	gtk_signal_connect_while_alive (GTK_OBJECT (check_button),
 					"focus_out_event",
-					GTK_SIGNAL_FUNC (button_focus_out_event_callback),
+					G_CALLBACK (button_focus_out_event_callback),
 					NULL,
 					GTK_OBJECT (check_button));
 	
@@ -1818,54 +1776,6 @@ eel_labeled_image_set_pixbuf_from_file_name (EelLabeledImage *labeled_image,
 	eel_image_set_pixbuf_from_file_name (EEL_IMAGE (labeled_image->details->image), pixbuf_file_name);
 }
 
-void
-eel_labeled_image_set_tile_pixbuf (EelLabeledImage *labeled_image,
-				   GdkPixbuf *tile_pixbuf)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-
-	if (labeled_image->details->image != NULL) {
-		eel_image_set_tile_pixbuf (EEL_IMAGE (labeled_image->details->image), tile_pixbuf);
-		eel_image_set_tile_mode_horizontal (EEL_IMAGE (labeled_image->details->image),
-						    EEL_SMOOTH_TILE_ANCESTOR);
-		eel_image_set_tile_mode_vertical (EEL_IMAGE (labeled_image->details->image),
-						  EEL_SMOOTH_TILE_ANCESTOR);
-	}
-
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_tile_pixbuf (EEL_LABEL (labeled_image->details->label), tile_pixbuf);
-		eel_label_set_tile_mode_horizontal (EEL_LABEL (labeled_image->details->label),
-						    EEL_SMOOTH_TILE_ANCESTOR);
-		eel_label_set_tile_mode_vertical (EEL_LABEL (labeled_image->details->label),
-						  EEL_SMOOTH_TILE_ANCESTOR);
-	}
-}
-
-void
-eel_labeled_image_set_tile_pixbuf_from_file_name (EelLabeledImage *labeled_image,
-						  const char *pixbuf_file_name)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-	
-	if (labeled_image->details->image != NULL) {
-		eel_image_set_tile_pixbuf_from_file_name (EEL_IMAGE (labeled_image->details->image),
-							  pixbuf_file_name);
-		eel_image_set_tile_mode_horizontal (EEL_IMAGE (labeled_image->details->image),
-						    EEL_SMOOTH_TILE_ANCESTOR);
-		eel_image_set_tile_mode_vertical (EEL_IMAGE (labeled_image->details->image),
-						  EEL_SMOOTH_TILE_ANCESTOR);
-	}
-
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_tile_pixbuf_from_file_name (EEL_LABEL (labeled_image->details->label),
-							  pixbuf_file_name);
-		eel_label_set_tile_mode_horizontal (EEL_LABEL (labeled_image->details->label),
-						    EEL_SMOOTH_TILE_ANCESTOR);
-		eel_label_set_tile_mode_vertical (EEL_LABEL (labeled_image->details->label),
-						  EEL_SMOOTH_TILE_ANCESTOR);
-	}
-}
-
 GdkPixbuf*
 eel_labeled_image_get_pixbuf (const EelLabeledImage *labeled_image)
 {
@@ -1905,7 +1815,7 @@ eel_labeled_image_set_text (EelLabeledImage *labeled_image,
 		gtk_widget_queue_resize (GTK_WIDGET (labeled_image));
 	} else {
 		labeled_image_ensure_label (labeled_image);
-		eel_label_set_text (EEL_LABEL (labeled_image->details->label), text);
+		gtk_label_set_text (GTK_LABEL (labeled_image->details->label), text);
 	}
 }
 
@@ -1918,152 +1828,5 @@ eel_labeled_image_get_text (const EelLabeledImage *labeled_image)
 		return NULL;
 	}
 
-	return eel_label_get_text (EEL_LABEL (labeled_image->details->label));
-}
-
-void
-eel_labeled_image_make_bold (EelLabeledImage *labeled_image)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-
-	labeled_image_ensure_label (labeled_image);
-	eel_label_make_bold (EEL_LABEL (labeled_image->details->label));
-}
-
-void
-eel_labeled_image_make_larger (EelLabeledImage *labeled_image,
-			       guint num_sizes)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-
-	labeled_image_ensure_label (labeled_image);
-	eel_label_make_larger (EEL_LABEL (labeled_image->details->label), num_sizes);
-}
-
-void
-eel_labeled_image_make_smaller (EelLabeledImage *labeled_image,
-				guint num_sizes)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-
-	labeled_image_ensure_label (labeled_image);
-	eel_label_make_smaller (EEL_LABEL (labeled_image->details->label), num_sizes);
-}
-
-void
-eel_labeled_image_set_tile_width (EelLabeledImage *labeled_image,
-				  int tile_width)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-
-	if (labeled_image->details->image != NULL) {
-		eel_image_set_tile_width (EEL_IMAGE (labeled_image->details->image),
-					  tile_width);
-	}
-
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_tile_width (EEL_LABEL (labeled_image->details->label),
-					  tile_width);
-	}
-}
-
-void
-eel_labeled_image_set_tile_height (EelLabeledImage *labeled_image,
-				   int tile_height)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-
-	if (labeled_image->details->image != NULL) {
-		eel_image_set_tile_height (EEL_IMAGE (labeled_image->details->image),
-					   tile_height);
-	}
-
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_tile_height (EEL_LABEL (labeled_image->details->label),
-					   tile_height);
-	}
-}
-
-void
-eel_labeled_image_set_background_mode (EelLabeledImage *labeled_image,
-				       EelSmoothBackgroundMode background_mode)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-	g_return_if_fail (background_mode >= EEL_SMOOTH_BACKGROUND_GTK);
-	g_return_if_fail (background_mode <= EEL_SMOOTH_BACKGROUND_SOLID_COLOR);
-
-	if (labeled_image->details->image != NULL) {
-		eel_image_set_background_mode (EEL_IMAGE (labeled_image->details->image),
-					       background_mode);
-	}
-
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_background_mode (EEL_LABEL (labeled_image->details->label),
-					       background_mode);
-	}
-}
-
-void
-eel_labeled_image_set_solid_background_color (EelLabeledImage *labeled_image,
-					      guint32 solid_background_color)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-	
-	if (labeled_image->details->image != NULL) {
-		eel_image_set_solid_background_color (EEL_IMAGE (labeled_image->details->image),
-						      solid_background_color);
-	}
-
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_solid_background_color (EEL_LABEL (labeled_image->details->label),
-						      solid_background_color);
-	}
-}
-
-void
-eel_labeled_image_set_smooth_drop_shadow_offset (EelLabeledImage *labeled_image,
-						 guint drop_shadow_offset)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-	
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_smooth_drop_shadow_offset (EEL_LABEL (labeled_image->details->label),
-							 drop_shadow_offset);
-	}
-}
-
-void
-eel_labeled_image_set_smooth_drop_shadow_color (EelLabeledImage *labeled_image,
-						guint32 drop_shadow_color)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-	
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_smooth_drop_shadow_color (EEL_LABEL (labeled_image->details->label),
-							drop_shadow_color);
-	}
-}
-
-void
-eel_labeled_image_set_text_color (EelLabeledImage *labeled_image,
-				  guint32 text_color)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_text_color (EEL_LABEL (labeled_image->details->label),
-					  text_color);
-	}
-}
-
-void
-eel_labeled_image_set_label_never_smooth (EelLabeledImage *labeled_image,
-					  gboolean never_smooth)
-{
-	g_return_if_fail (EEL_IS_LABELED_IMAGE (labeled_image));
-
-	if (labeled_image->details->label != NULL) {
-		eel_label_set_never_smooth (EEL_LABEL (labeled_image->details->label),
-					    never_smooth);
-	}
+	return g_strdup (gtk_label_get_text (GTK_LABEL (labeled_image->details->label)));
 }
