@@ -26,13 +26,14 @@
 #include <config.h>
 #include "eel-preferences-item.h"
 
-#include "eel-preferences.h"
 #include "eel-art-gtk-extensions.h"
 #include "eel-enumeration.h"
 #include "eel-font-picker.h"
 #include "eel-glib-extensions.h"
 #include "eel-gtk-extensions.h"
 #include "eel-gtk-macros.h"
+#include "eel-marshal.h"
+#include "eel-preferences.h"
 #include "eel-radio-button-group.h"
 #include "eel-string-picker.h"
 #include "eel-string.h"
@@ -74,10 +75,9 @@ typedef enum
 
 static guint preferences_item_signals[LAST_SIGNAL];
 
-/* GtkObjectClass methods */
-static void eel_preferences_item_initialize_class                     (EelPreferencesItemClass *preferences_item_class);
-static void eel_preferences_item_initialize                           (EelPreferencesItem      *preferences_item);
-static void preferences_item_destroy                                  (GtkObject               *object);
+static void eel_preferences_item_class_init                     (EelPreferencesItemClass *preferences_item_class);
+static void eel_preferences_item_init                           (EelPreferencesItem      *preferences_item);
+static void preferences_item_finalize                                 (GObject               *object);
 
 /* Private stuff */
 static void preferences_item_create_boolean                           (EelPreferencesItem      *item);
@@ -116,43 +116,42 @@ static void smooth_font_changed_callback                              (EelFontPi
 static void custom_changed_callback                                   (GtkWidget               *custom,
 								       gpointer                 user_data);
 
-EEL_DEFINE_CLASS_BOILERPLATE (EelPreferencesItem, eel_preferences_item, GTK_TYPE_VBOX)
+EEL_CLASS_BOILERPLATE (EelPreferencesItem, eel_preferences_item, GTK_TYPE_VBOX)
 
 /* EelPreferencesItemClass methods */
 static void
-eel_preferences_item_initialize_class (EelPreferencesItemClass *preferences_item_class)
+eel_preferences_item_class_init (EelPreferencesItemClass *preferences_item_class)
 {
 	GtkObjectClass *object_class;
 
 	object_class = GTK_OBJECT_CLASS (preferences_item_class);
 
 	/* GtkObjectClass */
-	object_class->destroy = preferences_item_destroy;
+	G_OBJECT_CLASS (preferences_item_class)->finalize = preferences_item_finalize;
 
 	/* Signals */
 	preferences_item_signals[CUSTOM_UPDATE_DISPLAYED_VALUE] = 
 		gtk_signal_new ("custom_update_displayed_value",
 				GTK_RUN_LAST,
-				object_class->type,
-				0,
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 
+				GTK_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (EelPreferencesItemClass, custom_update_displayed_value),
+				gtk_marshal_VOID__VOID,
+				G_TYPE_NONE, 
 				0);
 	preferences_item_signals[CUSTOM_DESCRIPTION_CHANGED] = 
-		gtk_signal_new ("custom_description_changed",
-				GTK_RUN_LAST,
-				object_class->type,
-				0,
-				gtk_marshal_NONE__POINTER_POINTER,
-				GTK_TYPE_NONE, 
-				2,
-				GTK_TYPE_OBJECT,
-				GTK_TYPE_STRING);
-	gtk_object_class_add_signals (object_class, preferences_item_signals, LAST_SIGNAL);
+ 		gtk_signal_new ("custom_description_changed",
+ 				GTK_RUN_LAST,
+ 				GTK_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (EelPreferencesItemClass, custom_update_description),
+				eel_marshal_VOID__POINTER_STRING,
+ 				G_TYPE_NONE, 
+ 				2,
+ 				GTK_TYPE_OBJECT,
+ 				GTK_TYPE_STRING);
 }
 
 static void
-eel_preferences_item_initialize (EelPreferencesItem *item)
+eel_preferences_item_init (EelPreferencesItem *item)
 {
 	item->details = g_new0 (EelPreferencesItemDetails, 1);
 	item->details->item_type = PREFERENCES_ITEM_UNDEFINED_ITEM;
@@ -161,11 +160,9 @@ eel_preferences_item_initialize (EelPreferencesItem *item)
 
 /* GtkObjectClass methods */
 static void
-preferences_item_destroy (GtkObject *object)
+preferences_item_finalize (GObject *object)
 {
-	EelPreferencesItem * item;
-	
-	g_return_if_fail (EEL_IS_PREFERENCES_ITEM (object));
+	EelPreferencesItem *item;
 	
 	item = EEL_PREFERENCES_ITEM (object);
 
@@ -175,8 +172,7 @@ preferences_item_destroy (GtkObject *object)
 	eel_string_list_free (item->details->enumeration_list_unique_exceptions);
 	g_free (item->details);
 
-	/* Chain destroy */
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /*
@@ -361,7 +357,7 @@ preferences_item_set_main_child (EelPreferencesItem *item,
 		eel_preferences_add_callback_while_alive (item->details->preference_name,
 							  preferences_item_value_changed_callback,
 							  item,
-							  GTK_OBJECT (item));
+							  G_OBJECT (item));
 	}
 
 	gtk_box_pack_start (GTK_BOX (item),
@@ -392,7 +388,7 @@ preferences_item_add_connection_child (EelPreferencesItem *item,
 
 	connection = g_new0 (PreferencesItemConnection, 1);
 	connection->widget = child;
-	connection->signal_id = gtk_signal_connect (GTK_OBJECT (child),
+	connection->signal_id = g_signal_connect (child,
 						    signal_name,
 						    signal,
 						    item);
@@ -433,7 +429,7 @@ preferences_item_create_enumeration_radio (EelPreferencesItem *item,
 	preferences_item_add_connection_child (item,
 					       child,
 					       "changed",
-					       GTK_SIGNAL_FUNC (enumeration_radio_changed_callback));
+					       G_CALLBACK (enumeration_radio_changed_callback));
 
 	preferences_item_set_main_child (item, child);
 }
@@ -446,6 +442,7 @@ preferences_item_create_enumeration_list (EelPreferencesItem *item,
  	guint j;
 	char *enumeration_id;
 	char *enum_description;
+	GConfValue *fallback;
 	EelStringList *default_value;
 	guint num_pickers;
 	GtkWidget *string_picker;
@@ -460,9 +457,14 @@ preferences_item_create_enumeration_list (EelPreferencesItem *item,
 	g_return_if_fail (eel_strlen (enumeration_id) > 0);
 	g_return_if_fail (eel_enumeration_id_get_length (enumeration_id) > 0);
 
-	/* FIXME: Hard coded user level */
-	default_value = eel_preferences_default_get_string_list (item->details->preference_name, 0);
+	fallback = eel_preferences_get_emergency_fallback (item->details->preference_name);
 
+	g_assert (fallback);
+
+	default_value = eel_gconf_value_get_eel_string_list (fallback);
+
+	gconf_value_free (fallback);
+	
 	num_pickers = eel_string_list_get_length (default_value);
 	g_return_if_fail (num_pickers > 0);
 	
@@ -516,7 +518,7 @@ preferences_item_create_enumeration_list (EelPreferencesItem *item,
 		preferences_item_add_connection_child (item,
 						       string_picker,
 						       "changed",
-						       GTK_SIGNAL_FUNC (enumeration_list_changed_callback));
+						       G_CALLBACK (enumeration_list_changed_callback));
 	}
  	g_free (enumeration_id);
 
@@ -549,7 +551,7 @@ preferences_item_create_boolean (EelPreferencesItem *item)
 	preferences_item_add_connection_child (item,
 					       child,
 					       "toggled",
-					       GTK_SIGNAL_FUNC (boolean_button_toggled_callback));
+					       G_CALLBACK (boolean_button_toggled_callback));
 				      
 	preferences_item_set_main_child (item, child);
 }
@@ -588,7 +590,7 @@ preferences_item_create_editable_string (EelPreferencesItem *item)
 	 * This is a Nautilus specific special case for the home uri preference,
 	 * in the future this should be generalized.
 	 */
- 	if (g_strcasecmp (item->details->preference_name, "preferences/home_uri") == 0) {
+ 	if (g_ascii_strcasecmp (item->details->preference_name, "preferences/home_uri") == 0) {
  		eel_text_caption_set_expand_tilde (EEL_TEXT_CAPTION (child), TRUE);
  	}
 	
@@ -597,7 +599,7 @@ preferences_item_create_editable_string (EelPreferencesItem *item)
 	preferences_item_add_connection_child (item,
 					       child,
 					       "changed",
-					       GTK_SIGNAL_FUNC (editable_string_changed_callback));
+					       G_CALLBACK (editable_string_changed_callback));
 
 	preferences_item_set_main_child (item, child);
 }
@@ -638,7 +640,7 @@ preferences_item_create_editable_integer (EelPreferencesItem *item)
 	preferences_item_add_connection_child (item,
 					       child,
 					       "changed",
-					       GTK_SIGNAL_FUNC (editable_integer_changed_callback));
+					       G_CALLBACK (editable_integer_changed_callback));
 
 	preferences_item_set_main_child (item, child);
 }
@@ -717,7 +719,7 @@ preferences_item_create_enumeration_menu (EelPreferencesItem *item)
 	preferences_item_add_connection_child (item,
 					       child,
 					       "changed",
-					       GTK_SIGNAL_FUNC (enumeration_menu_changed_callback));
+					       G_CALLBACK (enumeration_menu_changed_callback));
 
 	preferences_item_set_main_child (item, child);
 }
@@ -788,7 +790,7 @@ preferences_item_create_font (EelPreferencesItem *item)
 	preferences_item_add_connection_child (item,
 					       child,
 					       "changed",
-					       GTK_SIGNAL_FUNC (font_changed_callback));
+					       G_CALLBACK (font_changed_callback));
 	
 	preferences_item_set_main_child (item, child);
 }
@@ -848,7 +850,7 @@ preferences_item_create_smooth_font (EelPreferencesItem *item)
 	preferences_item_add_connection_child (item,
 					       child,
 					       "changed",
-					       GTK_SIGNAL_FUNC (smooth_font_changed_callback));
+					       G_CALLBACK (smooth_font_changed_callback));
 
 	preferences_item_set_main_child (item, child);
 }
@@ -956,7 +958,7 @@ eel_preferences_item_new_custom (const char *preference_name,
 	preferences_item_add_connection_child (item,
 					       child,
 					       signal_name,
-					       GTK_SIGNAL_FUNC (custom_changed_callback));
+					       G_CALLBACK (custom_changed_callback));
 
 	preferences_item_set_main_child (item, child);
 
@@ -1267,10 +1269,8 @@ update_integer_settings_at_idle (EelPreferencesItem *item)
 	char *text;
 
 	text = eel_text_caption_get_text (EEL_TEXT_CAPTION (item->details->main_child));
-
-	if (text != NULL) {
-		eel_eat_str_to_int (text, &value);
-	}
+	eel_str_to_int (text, &value);
+	g_free (text);
 	
 	eel_preferences_set_integer (item->details->preference_name, value);
 
@@ -1423,17 +1423,17 @@ eel_preferences_item_update_showing (EelPreferencesItem *item)
 void
 eel_preferences_item_enumeration_list_set_unique_exceptions (EelPreferencesItem *item,
 							     const char *exceptions,
-							     const char *exceptions_delimeter)
+							     const char *exceptions_delimiter)
 {
 	EelStringList *new_exceptions;
 
 	g_return_if_fail (EEL_IS_PREFERENCES_ITEM (item));
 	g_return_if_fail (item->details->item_type == EEL_PREFERENCE_ITEM_ENUMERATION_LIST_VERTICAL
 			  || item->details->item_type == EEL_PREFERENCE_ITEM_ENUMERATION_LIST_HORIZONTAL);
-	g_return_if_fail (eel_strlen (exceptions_delimeter) > 0);
+	g_return_if_fail (eel_strlen (exceptions_delimiter) > 0);
 
 	new_exceptions = eel_string_list_new_from_tokens (exceptions,
-							  exceptions_delimeter,
+							  exceptions_delimiter,
 							  TRUE);
 
 	if (eel_string_list_equals (new_exceptions, item->details->enumeration_list_unique_exceptions)) {
