@@ -58,10 +58,10 @@ G_STMT_START { \
 	eel_before_check (#expression, __FILE__, __LINE__); \
 	eel_check_point_result (expression, expected_x, expected_y); \
 } G_STMT_END
-#define EEL_CHECK_STRING_LIST_RESULT(expression, expected_value, expected_value_delimeter) \
+#define EEL_CHECK_STRING_LIST_RESULT(expression, expected_value, expected_value_delimiter) \
 G_STMT_START { \
 	eel_before_check (#expression, __FILE__, __LINE__); \
-	eel_check_string_list_result (expression, expected_value, expected_value_delimeter); \
+	eel_check_string_list_result (expression, expected_value, expected_value_delimiter); \
 } G_STMT_END
 
 void eel_exit_if_self_checks_failed (void);
@@ -96,7 +96,7 @@ void eel_check_string_result        (char          *result,
 				     const char    *expected_value);
 void eel_check_string_list_result   (EelStringList *result,
 				     const char    *expected_value,
-				     const char    *expected_value_delimeter);
+				     const char    *expected_value_delimiter);
 
 #define EEL_SELF_CHECK_FUNCTION_PROTOTYPE(function) \
 	void function (void);
