@@ -41,7 +41,6 @@
 #include <libgnomevfs/gnome-vfs-xfer.h>
 #include <pthread.h>
 
-#include <ctype.h>
 #include <string.h>
 
 #define READ_CHUNK_SIZE 8192
@@ -523,9 +522,10 @@ pthread_eel_read_file_async_cancel (EelReadFileHandle *handle)
 /* Set up the read handle and start reading. */
 EelReadFileHandle *
 eel_read_file_async (const char *uri,
-			  EelReadFileCallback callback,
-			  EelReadMoreCallback read_more_callback,
-			  gpointer callback_data)
+		     int priority,
+		     EelReadFileCallback callback,
+		     EelReadMoreCallback read_more_callback,
+		     gpointer callback_data)
 {
 #ifndef PTHREAD_ASYNC_READ
 	EelReadFileHandle *handle;
@@ -539,6 +539,7 @@ eel_read_file_async (const char *uri,
 	gnome_vfs_async_open (&handle->handle,
 			      uri,
 			      GNOME_VFS_OPEN_READ,
+			      priority,
 			      read_file_open_callback,
 			      handle);
 	return handle;
@@ -551,10 +552,11 @@ eel_read_file_async (const char *uri,
 /* Set up the read handle and start reading. */
 EelReadFileHandle *
 eel_read_entire_file_async (const char *uri,
-				 EelReadFileCallback callback,
-				 gpointer callback_data)
+			    int priority,
+			    EelReadFileCallback callback,
+			    gpointer callback_data)
 {
-	return eel_read_file_async (uri, callback, NULL, callback_data);
+	return eel_read_file_async (uri, priority, callback, NULL, callback_data);
 }
 
 /* Stop the presses! */
@@ -686,7 +688,7 @@ eel_format_uri_for_display (const char *uri)
 static gboolean
 is_valid_scheme_character (char c)
 {
-	return isalnum ((guchar) c) || c == '+' || c == '-' || c == '.';
+	return g_ascii_isalnum (c) || c == '+' || c == '-' || c == '.';
 }
 
 static gboolean
@@ -1261,9 +1263,7 @@ eel_make_uri_canonical (const char *uri)
 	/* Lower-case the scheme. */
 	for (p = canonical_uri; *p != ':'; p++) {
 		g_assert (*p != '\0');
-		if (isupper (*p)) {
-			*p = tolower (*p);
-		}
+		*p = g_ascii_tolower (*p);
 	}
 
 	if (!relative_uri) {
