@@ -2,7 +2,12 @@
 
 #include <eel/eel-background.h>
 #include <libgnomevfs/gnome-vfs-init.h>
-#include <gtk/gtk.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gtk/gtkctree.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtksignal.h>
+#include <gtk/gtkwidget.h>
+#include <gtk/gtkwindow.h>
 
 #define PATTERNS_DIR "/gnome-source/eel/data/patterns"
 
@@ -23,15 +28,15 @@ main  (int argc, char *argv[])
 #if 0
 	gtk_container_add (GTK_CONTAINER (window), ctree);
 #endif
-	gtk_signal_connect (GTK_OBJECT (window), "destroy",
+	g_signal_connect (window, "destroy",
 			    gtk_main_quit, NULL);
 
 	background = eel_get_widget_background (window);
 
 	eel_background_set_color (background,
-				       "red-blue:h");
+				  "red-blue:h");
 
-	image_uri = g_strconcat ("file://", PATTERNS_DIR, "/50s.png", NULL);
+	image_uri = gnome_vfs_get_uri_from_local_path (PATTERNS_DIR "/50s.png");
 
 #if 1
 	eel_background_set_image_uri (background, image_uri);
